@@ -4,7 +4,6 @@ import asyncio
 import logging
 from functools import wraps
 from inspect import isawaitable
-from multiprocessing.pool import ThreadPool
 from threading import RLock
 from time import sleep
 from typing import Any
@@ -41,7 +40,6 @@ class SingleBucketFactory(BucketFactory):
     def __init__(self, bucket: AbstractBucket, clock: AbstractClock):
         self.clock = clock
         self.bucket = bucket
-        self.thread_pool = ThreadPool(processes=1)
         self.schedule_leak(bucket, clock)
 
     def wrap_item(self, name: str, weight: int = 1):
@@ -50,10 +48,10 @@ class SingleBucketFactory(BucketFactory):
         async def wrap_async():
             return RateItem(name, await now, weight=weight)
 
-        def wrap_sycn():
+        def wrap_sync():
             return RateItem(name, now, weight=weight)
 
-        return wrap_async() if isawaitable(now) else wrap_sycn()
+        return wrap_async() if isawaitable(now) else wrap_sync()
 
     def get(self, _: RateItem) -> AbstractBucket:
         return self.bucket
@@ -68,7 +66,6 @@ class Limiter:
     raise_when_fail: bool
     max_delay: Optional[int] = None
     lock: RLock
-    thread_pool: Optional[ThreadPool] = None
 
     def __init__(
         self,
@@ -76,21 +73,11 @@ class Limiter:
         clock: AbstractClock = TimeClock(),
         raise_when_fail: bool = True,
         max_delay: Optional[Union[int, Duration]] = None,
-        thread_pool: Optional[ThreadPool] = None,
     ):
         """Init Limiter using either a single bucket / multiple-bucket factory
         / single rate / rate list
         """
         self.bucket_factory = self._init_bucket_factory(argument, clock=clock)
-
-        if thread_pool:
-            logger.info("Overriding BucketFactory's local thread-pool with Limiter's thread-pool")
-            self.bucket_factory.thread_pool = thread_pool
-
-        if self.bucket_factory.thread_pool is None:
-            logger.info("Create default thread-pool for Limiter with 10 processes")
-            self.bucket_factory.thread_pool = ThreadPool(processes=10)
-
         self.raise_when_fail = raise_when_fail
 
         if max_delay is not None:
@@ -102,6 +89,17 @@ class Limiter:
         self.max_delay = max_delay
         self.lock = RLock()
 
+    def buckets(self) -> List[AbstractBucket]:
+        """Get list of active buckets
+        """
+        return self.bucket_factory.get_buckets()
+
+    def dispose(self, bucket: Union[int, AbstractBucket]) -> bool:
+        """Dispose/Remove a specific bucket,
+        using bucket-id or bucket object as param
+        """
+        return self.bucket_factory.dispose(bucket)
+
     def _init_bucket_factory(
         self,
         argument: Union[BucketFactory, AbstractBucket, Rate, List[Rate]],
@@ -265,7 +263,7 @@ class Limiter:
         return _handle_result(acquire)  # type: ignore
 
     def try_acquire(self, name: str, weight: int = 1) -> Union[bool, Awaitable[bool]]:
-        """Try accquiring an item with name & weight
+        """Try acquiring an item with name & weight
         Return true on success, false on failure
         """
         with self.lock:
@@ -273,7 +271,7 @@ class Limiter:
 
             if weight == 0:
                 # NOTE: if item is weightless, just let it go through
-                # NOTE: this might change in the futre
+                # NOTE: this might change in the future
                 return True
 
             item = self.bucket_factory.wrap_item(name, weight)
@@ -284,6 +282,8 @@ class Limiter:
                     nonlocal item
                     item = await item
                     bucket = self.bucket_factory.get(item)
+                    if isawaitable(bucket):
+                        bucket = await bucket
                     assert isinstance(bucket, AbstractBucket), f"Invalid bucket: item: {name}"
                     result = self.handle_bucket_put(bucket, item)
 
@@ -296,6 +296,21 @@ class Limiter:
 
             assert isinstance(item, RateItem)  # NOTE: this is to silence mypy warning
             bucket = self.bucket_factory.get(item)
+            if isawaitable(bucket):
+
+                async def _handle_async_bucket():
+                    nonlocal bucket
+                    bucket = await bucket
+                    assert isinstance(bucket, AbstractBucket), f"Invalid bucket: item: {name}"
+                    result = self.handle_bucket_put(bucket, item)
+
+                    while isawaitable(result):
+                        result = await result
+
+                    return result
+
+                return _handle_async_bucket()
+
             assert isinstance(bucket, AbstractBucket), f"Invalid bucket: item: {name}"
             result = self.handle_bucket_put(bucket, item)
 
